# crownstone-lib-python-core

This is the core of the python lib. It contains shared classes, definitions and utils. This is not meant for use by external
parties directly. Take a a look at the specialized libraries for your purpose:

crownstone-lib-python-sse
crownstone-lib-python-cloud
crownstone-lib-python-uart
crownstone-lib-python-ble